"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
Object.defineProperty(exports, "inlineStaticEnv", {
    enumerable: true,
    get: function() {
        return inlineStaticEnv;
    }
});
const _fs = /*#__PURE__*/ _interop_require_default(require("fs"));
const _path = /*#__PURE__*/ _interop_require_default(require("path"));
const _util = require("util");
const _glob = /*#__PURE__*/ _interop_require_default(require("next/dist/compiled/glob"));
const _defineenvplugin = require("../webpack/plugins/define-env-plugin");
const _asyncsema = require("next/dist/compiled/async-sema");
function _interop_require_default(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
const glob = (0, _util.promisify)(_glob.default);
async function inlineStaticEnv({ distDir }) {
    const staticEnv = (0, _defineenvplugin.getNextPublicEnvironmentVariables)();
    const serverDir = _path.default.join(distDir, 'server');
    const serverChunks = await glob('**/*.js', {
        cwd: serverDir
    });
    const clientDir = _path.default.join(distDir, 'static');
    const clientChunks = await glob('**/*.js', {
        cwd: clientDir
    });
    const inlineSema = new _asyncsema.Sema(8);
    for (const [parentDir, files] of [
        [
            serverDir,
            serverChunks
        ],
        [
            clientDir,
            clientChunks
        ]
    ]){
        await Promise.all(files.map(async (file)=>{
            await inlineSema.acquire();
            const filepath = _path.default.join(parentDir, file);
            const content = await _fs.default.promises.readFile(filepath, 'utf8');
            // TODO: should we support process.env['NEXT_PUBLIC_KEY'] format?
            await _fs.default.promises.writeFile(filepath, content.replace(/['"`]?[\w]{1,}\.env\.[\w]{1,}['"`]?/g, (match)=>{
                const matchParts = match.split('.');
                let normalizedMatch = `process.env.${matchParts[2].replace(// remove ending quote if present
                /['"`]$/, '')}`;
                if (staticEnv[normalizedMatch]) {
                    return JSON.stringify(staticEnv[normalizedMatch]);
                }
                return match;
            }));
            inlineSema.release();
        }));
    }
}

//# sourceMappingURL=inline-static-env.js.map